( cd usr/lib/mozilla-1.7.2/plugins ; rm -rf libjavaplugin_oji.so )
( cd usr/lib/mozilla-1.7.2/plugins ; ln -sf /usr/lib/java/jre/plugin/i386/ns610-gcc32/libjavaplugin_oji.so libjavaplugin_oji.so )
( cd usr/lib/mozilla-1.7.2/plugins ; rm -rf libflashplayer.so )
( cd usr/lib/mozilla-1.7.2/plugins ; ln -sf /usr/lib/netscape/plugins/libflashplayer.so libflashplayer.so )
